Class: OpenTelemetry::Instrumentation::Net::HTTP::Instrumentation
- Inherits:
-
Base
- Object
- Base
- OpenTelemetry::Instrumentation::Net::HTTP::Instrumentation
- Defined in:
- lib/opentelemetry/instrumentation/net/http/instrumentation.rb
Overview
The Instrumentation class contains logic to detect and install the Net::HTTP instrumentation
Instance Method Summary collapse
-
#untraced_hosts ⇒ Object
Supported configuration keys for the install config hash:.
Instance Method Details
#untraced_hosts ⇒ Object
Supported configuration keys for the install config hash:
untraced_hosts: if a request's address matches any of the String
or Regexp in this array, the instrumentation will not record a
kind = :client representing the request and will not propagate
context in the request.
30 |
# File 'lib/opentelemetry/instrumentation/net/http/instrumentation.rb', line 30 option :untraced_hosts, default: [], validate: :array |